@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2010 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -421,12 +421,12 @@ g_mime_signer_new (void)
 {
 	GMimeSigner *signer;
 	
-	signer = g_new (GMimeSigner, 1);
+	signer = g_slice_new (GMimeSigner);
 	signer->status = GMIME_SIGNER_STATUS_NONE;
 	signer->errors = GMIME_SIGNER_ERROR_NONE;
 	signer->trust = GMIME_SIGNER_TRUST_NONE;
-	signer->created = (time_t) 0;
-	signer->expires = (time_t) 0;
+	signer->created = (time_t) -1;
+	signer->expires = (time_t) -1;
 	signer->fingerprint = NULL;
 	signer->keyid = NULL;
 	signer->name = NULL;
@@ -440,7 +440,8 @@ g_mime_signer_new (void)
  * g_mime_signer_free:
  * @signer: signer
  *
- * Free's the singleton signer.
+ * Frees a singleton signer. Should NOT be used to free signers
+ * returned from g_mime_signature_validity_get_signers().
  **/
 void
 g_mime_signer_free (GMimeSigner *signer)
@@ -448,7 +449,8 @@ g_mime_signer_free (GMimeSigner *signer)
 	g_free (signer->fingerprint);
 	g_free (signer->keyid);
 	g_free (signer->name);
-	g_free (signer);
+	
+	g_slice_free (GMimeSigner, signer);
 }
 
 
@@ -494,7 +496,7 @@ g_mime_signer_set_status (GMimeSigner *signer, GMimeSignerStatus status)
  * Returns: the signer status.
  **/
 GMimeSignerStatus
-g_mime_signer_get_status (GMimeSigner *signer)
+g_mime_signer_get_status (const GMimeSigner *signer)
 {
 	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_STATUS_NONE);
 	
@@ -527,7 +529,7 @@ g_mime_signer_set_errors (GMimeSigner *signer, GMimeSignerError errors)
  * Returns: the signer errors.
  **/
 GMimeSignerError
-g_mime_signer_get_errors (GMimeSigner *signer)
+g_mime_signer_get_errors (const GMimeSigner *signer)
 {
 	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_ERROR_NONE);
 	
@@ -560,7 +562,7 @@ g_mime_signer_set_trust (GMimeSigner *signer, GMimeSignerTrust trust)
  * Returns: the signer trust.
  **/
 GMimeSignerTrust
-g_mime_signer_get_trust (GMimeSigner *signer)
+g_mime_signer_get_trust (const GMimeSigner *signer)
 {
 	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_TRUST_NONE);
 	
@@ -594,7 +596,7 @@ g_mime_signer_set_fingerprint (GMimeSigner *signer, const char *fingerprint)
  * Returns: the signer's key fingerprint.
  **/
 const char *
-g_mime_signer_get_fingerprint (GMimeSigner *signer)
+g_mime_signer_get_fingerprint (const GMimeSigner *signer)
 {
 	g_return_val_if_fail (signer != NULL, NULL);
 	
@@ -628,7 +630,7 @@ g_mime_signer_set_key_id (GMimeSigner *signer, const char *key_id)
  * Returns: the signer's key id.
  **/
 const char *
-g_mime_signer_get_key_id (GMimeSigner *signer)
+g_mime_signer_get_key_id (const GMimeSigner *signer)
 {
 	g_return_val_if_fail (signer != NULL, NULL);
 	
@@ -657,12 +659,12 @@ g_mime_signer_set_name (GMimeSigner *signer, const char *name)
  * g_mime_signer_get_name:
  * @signer: a #GMimeSigner
  *
- * Get the signer trust.
+ * Get the signer's name.
  *
- * Returns: the signer trust.
+ * Returns: the signer's name.
  **/
 const char *
-g_mime_signer_get_name (GMimeSigner *signer)
+g_mime_signer_get_name (const GMimeSigner *signer)
 {
 	g_return_val_if_fail (signer != NULL, NULL);
 	
@@ -692,10 +694,10 @@ g_mime_signer_set_created (GMimeSigner *signer, time_t created)
  *
  * Get the creation date of the signer's key.
  *
- * Returns: the creation date of the signer's key.
+ * Returns: the creation date of the signer's key or %-1 if unknown.
  **/
 time_t
-g_mime_signer_get_created (GMimeSigner *signer)
+g_mime_signer_get_created (const GMimeSigner *signer)
 {
 	g_return_val_if_fail (signer != NULL, (time_t) -1);
 	
@@ -725,10 +727,10 @@ g_mime_signer_set_expires (GMimeSigner *signer, time_t expires)
  *
  * Get the expiration date of the signer's key.
  *
- * Returns: the expiration date of the signer's key.
+ * Returns: the expiration date of the signer's key or %-1 if unknown.
  **/
 time_t
-g_mime_signer_get_expires (GMimeSigner *signer)
+g_mime_signer_get_expires (const GMimeSigner *signer)
 {
 	g_return_val_if_fail (signer != NULL, (time_t) -1);
 	
@@ -748,7 +750,7 @@ g_mime_signature_validity_new (void)
 {
 	GMimeSignatureValidity *validity;
 	
-	validity = g_new (GMimeSignatureValidity, 1);
+	validity = g_slice_new (GMimeSignatureValidity);
 	validity->status = GMIME_SIGNATURE_STATUS_NONE;
 	validity->signers = NULL;
 	validity->details = NULL;
@@ -774,16 +776,13 @@ g_mime_signature_validity_free (GMimeSignatureValidity *validity)
 	signer = validity->signers;
 	while (signer != NULL) {
 		next = signer->next;
-		g_free (signer->fingerprint);
-		g_free (signer->keyid);
-		g_free (signer->name);
-		g_free (signer);
+		g_mime_signer_free (signer);
 		signer = next;
 	}
 	
 	g_free (validity->details);
 	
-	g_free (validity);
+	g_slice_free (GMimeSignatureValidity, validity);
 }
 
 
@@ -862,7 +861,8 @@ g_mime_signature_validity_set_details (GMimeSignatureValidity *validity, const c
  * Gets the list of signers.
  *
  * Returns: a #GMimeSigner list which contain further information such
- * as trust and cipher keys.
+ * as trust and cipher keys. These signers are part of the
+ * #GMimeSignatureValidity and should NOT be freed individually.
  **/
 const GMimeSigner *
 g_mime_signature_validity_get_signers (const GMimeSignatureValidity *validity)
@@ -878,7 +878,8 @@ g_mime_signature_validity_get_signers (const GMimeSignatureValidity *validity)
  * @validity: signature validity
  * @signer: signer
  *
- * Adds @signer to the list of signers on @validity.
+ * Adds @signer to the list of signers on @validity. Once the signer
+ * is added, it must NOT be freed.
  **/
 void
 g_mime_signature_validity_add_signer  (GMimeSignatureValidity *validity, GMimeSigner *signer)
